@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Request::Current;
-$Weather::OpenWeatherMap::Request::Current::VERSION = '0.001001';
+$Weather::OpenWeatherMap::Request::Current::VERSION = '0.001002';
 use Moo;
 extends 'Weather::OpenWeatherMap::Request';
 
@@ -15,11 +15,12 @@ Weather::OpenWeatherMap::Request::Current
 
 =head1 SYNOPSIS
 
+  # Usually created by Weather::OpenWeatherMap
   use Weather::OpenWeatherMap::Request;
   my $current = Weather::OpenWeatherMap::Request->new_for(
     Current =>
       tag      => 'foo',
-      location =>
+      location => 'Manchester, NH',
   );
 
 =head1 DESCRIPTION
